@@ -79,7 +79,7 @@ autosectionlabel_prefix_document = True
 # Example configuration for intersphinx: refer to the Python standard library.
 intersphinx_mapping = dict(
     python=("https://docs.python.org/3", None),
-    twisted=("https://twistedmatrix.com/documents/current/api/", None),
+    twisted=("https://docs.twistedmatrix.com/en/stable/api/", None),
 )
 
 # -- Options for the linkcheck builder ------------------------------------
