@@ -111,6 +111,15 @@ class TestObjectLocator(TestCase):
             [AttributeLoader(cls=TestFoo, attribute="test_F0")],
         )
 
+    def test_it_loads_methods_from_test_case_classes_with_mixin_methods(self):
+        locator = locators.ObjectLocator()
+        from virtue.tests.samples.mixin import TestFoo
+        name = "virtue.tests.samples.mixin.TestFoo.test_baz"
+        self.assertEqual(
+            list(locator.locate_by_name(name)),
+            [AttributeLoader(cls=TestFoo, attribute="test_baz")],
+        )
+
     def test_it_finds_test_case_classes_on_modules(self):
         locator = locators.ObjectLocator(
             is_test_class=(lambda attr, value: attr != "Foo"),
@@ -163,7 +172,7 @@ class TestObjectLocator(TestCase):
         )
 
     def test_it_knows_what_it_does_not_know(self):
-        with self.assertRaises(ValueError):
+        with self.assertRaises(locators.UnableToLoad):
             locators.ObjectLocator().locate_in(object())
 
     def create_package_with_tests(self, locator):
